@@ -1,5 +1,5 @@
 /* anonymous.h	header file for SASL mechanism ANONYMOUS as defined in RFC 2245
- * Copyright (C) 2002  Simon Josefsson
+ * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -22,6 +22,10 @@
 #ifndef _ANONYMOUS_H
 #define _ANONYMOUS_H
 
+#include "internal.h"
+
+#ifdef USE_ANONYMOUS
+
 #define _GSASL_ANONYMOUS_NAME "ANONYMOUS"
 
 extern int _gsasl_anonymous_client_init (Gsasl_ctx * ctx);
@@ -48,4 +52,6 @@ extern int _gsasl_anonymous_server_step (Gsasl_session_ctx * sctx,
 extern int _gsasl_anonymous_server_finish (Gsasl_session_ctx * sctx,
 					   void *mech_data);
 
+#endif /* USE_ANONYMOUS */
+
 #endif /* _ANONYMOUS_H */
