@@ -1,5 +1,5 @@
 /* gsasl.h	header file for libgsasl                              -*- c -*-
- * Copyright (C) 2002  Simon Josefsson
+ * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -32,7 +32,7 @@ extern "C" {
 #endif
 #endif
 
-#define GSASL_VERSION "0.0.5"
+#define GSASL_VERSION "0.0.6"
 
 /* Quoting RFC 2222:
    SASL mechanisms are named by strings, from 1 to 20 characters in
@@ -65,6 +65,8 @@ enum {
   GSASL_GSSAPI_ACQUIRE_CRED_ERROR,
   GSASL_GSSAPI_DISPLAY_NAME_ERROR,
   GSASL_GSSAPI_UNSUPPORTED_PROTECTION_ERROR,
+  GSASL_KERBEROS_V5_INIT_ERROR,
+  GSASL_SHISHI_ERROR,
   GSASL_NEED_CLIENT_ANONYMOUS_CALLBACK,
   GSASL_NEED_CLIENT_PASSWORD_CALLBACK,
   GSASL_NEED_CLIENT_PASSCODE_CALLBACK,
@@ -81,6 +83,7 @@ enum {
   GSASL_NEED_SERVER_SECURID_CALLBACK,
   GSASL_NEED_SERVER_SERVICE_CALLBACK,
   GSASL_NEED_SERVER_GSSAPI_CALLBACK,
+  GSASL_NEED_SERVER_RETRIEVE_CALLBACK,
   GSASL_SECURID_SERVER_NEED_ADDITIONAL_PASSCODE,
   GSASL_SECURID_SERVER_NEED_NEW_PIN,
   GSASL_UNICODE_NORMALIZATION_ERROR,
@@ -211,6 +214,9 @@ typedef Gsasl_qop (*Gsasl_client_callback_qop) (Gsasl_session_ctx *sctx,
 						Gsasl_qop serverqops);
 typedef int (*Gsasl_client_callback_maxbuf) (Gsasl_session_ctx *sctx,
 					     int servermaxbuf);
+typedef int (*Gsasl_client_callback_realm) (Gsasl_session_ctx *sctx,
+					    char *out,
+					    size_t *outlen);
 typedef int (*Gsasl_server_callback_retrieve) (Gsasl_session_ctx *sctx,
 					       const char *authentication_id,
 					       const char *authorization_id,
@@ -306,6 +312,10 @@ extern void gsasl_client_callback_maxbuf_set (Gsasl_ctx *ctx,
 					      Gsasl_client_callback_maxbuf cb);
 extern Gsasl_client_callback_maxbuf
 	gsasl_client_callback_maxbuf_get (Gsasl_ctx *ctx);
+extern void gsasl_client_callback_realm_set (Gsasl_ctx * ctx,
+					     Gsasl_client_callback_realm cb);
+extern Gsasl_client_callback_realm
+	gsasl_client_callback_realm_get (Gsasl_ctx * ctx);
 
 /* Server callbacks */
 extern Gsasl_ctx *gsasl_server_ctx_get (Gsasl_session_ctx *sctx);
