@@ -1,5 +1,5 @@
 /* plain.h	header file for SASL mechanism PLAIN as defined in RFC 2595
- * Copyright (C) 2002  Simon Josefsson
+ * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -22,6 +22,10 @@
 #ifndef _PLAIN_H
 #define _PLAIN_H
 
+#include "internal.h"
+
+#ifdef USE_PLAIN
+
 #define _GSASL_PLAIN_NAME "PLAIN"
 
 extern int _gsasl_plain_client_init (Gsasl_ctx * ctx);
@@ -48,4 +52,6 @@ extern int _gsasl_plain_server_step (Gsasl_session_ctx * sctx,
 extern int _gsasl_plain_server_finish (Gsasl_session_ctx * sctx,
 				       void *mech_data);
 
+#endif /* USE_PLAIN */
+
 #endif /* _PLAIN_H */
