@@ -1,5 +1,5 @@
 /* securid.c	implementation of SASL mechanism SECURID as defined in RFC 2808
- * Copyright (C) 2002  Simon Josefsson
+ * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -19,7 +19,7 @@
  *
  */
 
-#include "internal.h"
+#include "securid.h"
 
 #ifdef USE_SECURID
 
