@@ -1,5 +1,5 @@
 /* gssapi.h	header file for SASL mechanism GSSAPI as defined in RFC 2222
- * Copyright (C) 2002  Simon Josefsson
+ * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -22,6 +22,10 @@
 #ifndef _GSSAPI_H
 #define _GSSAPI_H
 
+#include "internal.h"
+
+#if USE_GSSAPI
+
 #define _GSASL_GSSAPI_NAME "GSSAPI"
 
 extern int _gsasl_gssapi_client_init (Gsasl_ctx * ctx);
@@ -48,4 +52,6 @@ extern int _gsasl_gssapi_server_step (Gsasl_session_ctx * sctx,
 extern int _gsasl_gssapi_server_finish (Gsasl_session_ctx * sctx,
 					void *mech_data);
 
+#endif /* USE_GSSAPI */
+
 #endif /* _GSSAPI_H */
