@@ -1,5 +1,5 @@
 /* xstep.c	perform one SASL authentication step
- * Copyright (C) 2002  Simon Josefsson
+ * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -96,7 +96,7 @@ _gsasl_session_step_base64 (Gsasl_session_ctx * sctx,
       input = (char *) malloc (input_len);
 
       input_len = gsasl_base64_decode (b64input, input, input_len);
-      if (input_len == -1)
+      if ((int)input_len == -1)
 	{
 	  free (input);
 	  return GSASL_BASE64_ERROR;
@@ -130,7 +130,7 @@ _gsasl_session_step_base64 (Gsasl_session_ctx * sctx,
     {
       output_len = gsasl_base64_encode (output, output_len,
 					b64output, b64output_len);
-      if (output_len == -1)
+      if ((int)output_len == -1)
 	{
 	  free (output);
 	  free (input);
