@@ -1,5 +1,5 @@
 /* gsasl.c	command line interface to libgsasl
- * Copyright (C) 2002  Simon Josefsson
+ * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -142,6 +142,8 @@ parse_opt (int key, char *arg, struct argp_state *state)
 
     case OPTION_IMAP:
       imap = 1;
+      if (!service)
+	service = strdup ("imap");
       /* fall through */
 
     case OPTION_NO_CLIENT_FIRST:
@@ -178,52 +180,55 @@ parse_opt (int key, char *arg, struct argp_state *state)
       break;
 
     case OPTION_CONNECT:
-      if (strrchr(arg, ':'))
+      if (strrchr (arg, ':'))
 	{
-	  connect_hostname = strdup(arg);
-	  *strrchr(connect_hostname, ':') = '\0';
-	  connect_service = strdup(strrchr(arg, ':') + 1);
+	  connect_hostname = strdup (arg);
+	  *strrchr (connect_hostname, ':') = '\0';
+	  connect_service = strdup (strrchr (arg, ':') + 1);
 	}
       else
 	{
-	  connect_hostname = strdup(arg);
-	  connect_service = strdup("143");
+	  connect_hostname = strdup (arg);
+	  connect_service = strdup ("143");
 	}
       {
 	struct servent *se;
 	struct hostent *he;
-	struct sockaddr_in *sinaddr_inp = (struct sockaddr_in *) &connect_addr;
+	struct sockaddr_in *sinaddr_inp =
+	  (struct sockaddr_in *) &connect_addr;
 
 	he = gethostbyname (connect_hostname);
 	if (!he || he->h_addr_list[0] == NULL || he->h_addrtype != AF_INET)
 	  argp_error (state, "unknown host: %s", connect_hostname);
-	memset (sinaddr_inp, 0, sizeof (*sinaddr_inp));
+	memset (&connect_addr, 0, sizeof (connect_addr));
 	sinaddr_inp->sin_family = he->h_addrtype;
 	memcpy (&sinaddr_inp->sin_addr, he->h_addr_list[0], he->h_length);
-	se = getservbyname(connect_service, "tcp");
+	se = getservbyname (connect_service, "tcp");
 	if (se)
 	  sinaddr_inp->sin_port = se->s_port;
 	else
-	  sinaddr_inp->sin_port = htons(atoi(connect_service));
-	if (sinaddr_inp->sin_port == 0 || sinaddr_inp->sin_port == htons(0))
-	  argp_error(state, "unknown service: %s", connect_service);
+	  sinaddr_inp->sin_port = htons (atoi (connect_service));
+	if (sinaddr_inp->sin_port == 0 || sinaddr_inp->sin_port == htons (0))
+	  argp_error (state, "unknown service: %s", connect_service);
 
 	sockfd = socket (AF_INET, SOCK_STREAM, 0);
 	if (sockfd < 0)
 	  {
-	    perror("socket()");
-	    argp_error (state, "socket: %s", strerror(errno));
+	    perror ("socket()");
+	    argp_error (state, "socket: %s", strerror (errno));
 	  }
 
-	if (connect(sockfd, &connect_addr, sizeof(connect_addr)) < 0)
+	if (connect (sockfd, &connect_addr, sizeof (connect_addr)) < 0)
 	  {
-	    perror("connect()");
+	    perror ("connect()");
 	    close (sockfd);
-	    argp_error (state, "connect: %s", strerror(errno));
+	    argp_error (state, "connect: %s", strerror (errno));
 	  }
 	sockfh = fdopen (sockfd, "r+");
-	setvbuf(sockfh, NULL, _IONBF, 0);
+	setvbuf (sockfh, NULL, _IONBF, 0);
       }
+      if (!hostname)
+	hostname = strdup (connect_hostname);
       break;
 
     case ARGP_KEY_ARG:
@@ -275,7 +280,8 @@ static struct argp_option options[] = {
    "The default is to terminate after authentication."},
 
   {"imap", OPTION_IMAP, 0, 0,
-   "Use a IMAP-like logon procedure (client only)."},
+   "Use a IMAP-like logon procedure (client only). "
+   "Also sets the --service default to \"imap\"."},
 
   {"mechanism", 'm', "STRING", 0,
    "Mechanism to use."},
@@ -354,8 +360,15 @@ writeln (char *str)
 {
   printf ("%s\n", str);
 
-  if (sockfh && fprintf(sockfh, "%s\r\n", str) < strlen(str) + strlen("\r\n"))
-    return 0;
+  if (sockfh)
+    {
+      int len;
+
+      len = fprintf (sockfh, "%s\r\n", str);
+
+      if (len != (int) strlen (str) + (int)strlen ("\r\n"))
+	return 0;
+    }
 
   return 1;
 }
@@ -371,7 +384,7 @@ readln (char *buf, size_t maxbuflen)
     buf[strlen (buf) - 1] = '\0';
 
   if (sockfh)
-    printf("%s\n", buf);
+    printf ("%s\n", buf);
 
   return 1;
 }
@@ -383,7 +396,10 @@ main (int argc, char *argv[])
   int res;
   char input[MAX_LINE_LENGTH];
 
+#ifdef HAVE_LOCALE_H
   setlocale (LC_ALL, "");
+#endif
+  bindtextdomain (PACKAGE, LOCALEDIR);
 
   argp_parse (&argp, argc, argv, 0, 0, NULL);
 
@@ -408,6 +424,7 @@ main (int argc, char *argv[])
   gsasl_client_callback_password_set (ctx, client_callback_password);
   gsasl_client_callback_passcode_set (ctx, client_callback_passcode);
   gsasl_client_callback_service_set (ctx, client_callback_service);
+  gsasl_client_callback_realm_set (ctx, client_callback_realm);
 
   gsasl_server_callback_realm_set (ctx, server_callback_realm);
   gsasl_server_callback_qop_set (ctx, server_callback_qop);
@@ -449,7 +466,7 @@ main (int argc, char *argv[])
       fprintf (stdout, "%s\n", mechs);
     }
 
-  if (imap && !readln(input, MAX_LINE_LENGTH))
+  if (imap && !readln (input, MAX_LINE_LENGTH))
     return 1;
 
   if (mode == 'c' || mode == 's')
@@ -468,14 +485,14 @@ main (int argc, char *argv[])
 	{
 	  if (!silent)
 	    fprintf (stderr, _("Chose SASL mechanisms:\n"));
-	  if (!readln(input, MAX_LINE_LENGTH))
+	  if (!readln (input, MAX_LINE_LENGTH))
 	    return 1;
 
 	  if (!silent)
 	    fprintf (stderr, _("Chosed mechanism `%s'\n"), input);
 	  mech = input;
 	}
-      else /* if (mode == 'c') */
+      else			/* if (mode == 'c') */
 	{
 	  if (mechanism)
 	    {
@@ -483,17 +500,17 @@ main (int argc, char *argv[])
 	    }
 	  else
 	    {
-	      if (imap && !writeln(". CAPABILITY"))
+	      if (imap && !writeln (". CAPABILITY"))
 		return 1;
 
 	      if (!silent && !imap)
 		fprintf (stderr,
 			 _("Input SASL mechanism supported by server:\n"));
-	      if (!readln(input, MAX_LINE_LENGTH))
+	      if (!readln (input, MAX_LINE_LENGTH))
 		return 1;
 
 	      if (imap)
-		/* XXX parse IMAP capability line */;
+		/* XXX parse IMAP capability line */ ;
 
 	      mech = gsasl_client_suggest_mechanism (ctx, input);
 	      if (mech == NULL)
@@ -505,15 +522,15 @@ main (int argc, char *argv[])
 
 	  if (imap)
 	    {
-	      sprintf(input, ". AUTHENTICATE %s", mech);
-	      if (!writeln(input))
+	      sprintf (input, ". AUTHENTICATE %s", mech);
+	      if (!writeln (input))
 		return 1;
 	    }
 	  else
 	    {
 	      if (!silent)
 		fprintf (stderr, _("Libgsasl wants to use:\n"));
-	      puts(mech);
+	      puts (mech);
 	    }
 	}
 
@@ -552,8 +569,8 @@ main (int argc, char *argv[])
 
 	  if (imap)
 	    {
-	      sprintf(input, "+ %s", output);
-	      if (!writeln(output))
+	      sprintf (input, "+ %s", output);
+	      if (!writeln (output))
 		return 1;
 	    }
 	  else
@@ -577,7 +594,7 @@ main (int argc, char *argv[])
 			       "(press RET if none):\n"),
 		     mode == 'c' ? _("server") : _("client"));
 
-	  if (!readln(input, MAX_LINE_LENGTH))
+	  if (!readln (input, MAX_LINE_LENGTH))
 	    return 1;
 
 	  if (imap)
@@ -586,11 +603,10 @@ main (int argc, char *argv[])
 		{
 		  fprintf (stderr,
 			   _("error: Server did not return expected SASL "
-			     "data (it must begin with '+ '):\n%s\n"),
-			   input);
+			     "data (it must begin with '+ '):\n%s\n"), input);
 		  return 1;
 		}
-	      strcpy(&input[0], &input[2]);
+	      strcpy (&input[0], &input[2]);
 	    }
 	}
       while (res == GSASL_NEEDS_MORE);
@@ -603,12 +619,9 @@ main (int argc, char *argv[])
 	}
 
       /* wait for possibly last round trip */
-      if (imap && !readln(input, MAX_LINE_LENGTH))
+      if (imap && !readln (input, MAX_LINE_LENGTH))
 	return 1;
 
-      if (imap)
-	/* XXX check server outcome (NO vs OK vs still waiting) */;
-
       if (!silent)
 	{
 	  if (mode == 'c')
@@ -619,34 +632,35 @@ main (int argc, char *argv[])
 			       "finished (client trusted)...\n"));
 	}
 
+      if (imap)
+	/* XXX check server outcome (NO vs OK vs still waiting) */ ;
+
       /* Transfer application payload */
       if (application_data)
 	{
 	  fd_set readfds;
-	  int rc;
 
-	  FD_ZERO(&readfds);
-	  FD_SET(STDIN_FILENO, &readfds);
+	  FD_ZERO (&readfds);
+	  FD_SET (STDIN_FILENO, &readfds);
 	  if (sockfh)
-	    FD_SET(sockfd, &readfds);
+	    FD_SET (sockfd, &readfds);
 
 	  if (!silent)
-	    fprintf (stderr,
-		     _("Enter application data (EOF to finish):\n"));
+	    fprintf (stderr, _("Enter application data (EOF to finish):\n"));
 
-	  while (select(sockfd + 1, &readfds, NULL, NULL, NULL))
+	  while (select (sockfd + 1, &readfds, NULL, NULL, NULL))
 	    {
-	      if (FD_ISSET(STDIN_FILENO, &readfds))
+	      if (FD_ISSET (STDIN_FILENO, &readfds))
 		{
 		  input[0] = '\0';
-		  if (fgets (input, MAX_LINE_LENGTH-2, stdin) == NULL)
+		  if (fgets (input, MAX_LINE_LENGTH - 2, stdin) == NULL)
 		    break;
 		  if (imap)
 		    {
 		      int pos = strlen (input);
-		      input[pos-1] = '\r';
+		      input[pos - 1] = '\r';
 		      input[pos] = '\n';
-		      input[pos+1] = '\0';
+		      input[pos + 1] = '\0';
 		    }
 		  else
 		    input[strlen (input) - 1] = '\0';
@@ -657,10 +671,10 @@ main (int argc, char *argv[])
 		  if (res != GSASL_OK)
 		    break;
 
-		  if (!(strlen(input) == output_len &&
-			memcmp(input, output, output_len) == 0))
+		  if (!(strlen (input) == output_len &&
+			memcmp (input, output, output_len) == 0))
 		    {
-		      puts("d");
+		      puts ("d");
 		      b64output_len = sizeof (b64output);
 		      b64output_len = gsasl_base64_encode (output, output_len,
 							   b64output,
@@ -679,25 +693,25 @@ main (int argc, char *argv[])
 
 		  if (sockfh)
 		    {
-		      if (fwrite(output, sizeof(output[0]),
-				 output_len, sockfh) != output_len)
+		      if (fwrite (output, sizeof (output[0]),
+				  output_len, sockfh) != output_len)
 			return 0;
 		    }
 		}
 
-	      if (sockfd && FD_ISSET(sockfd, &readfds))
+	      if (sockfd && FD_ISSET (sockfd, &readfds))
 		{
 		  input[0] = '\0';
 		  if (fgets (input, MAX_LINE_LENGTH, sockfh) == NULL)
 		    break;
 		  input[strlen (input) - 1] = '\0';
-		  printf("s: %s\n", input);
+		  printf ("%s\n", input);
 		}
 
-	      FD_ZERO(&readfds);
-	      FD_SET(STDIN_FILENO, &readfds);
+	      FD_ZERO (&readfds);
+	      FD_SET (STDIN_FILENO, &readfds);
 	      if (sockfh)
-		FD_SET(sockfd, &readfds);
+		FD_SET (sockfd, &readfds);
 	    }
 
 	  if (res != GSASL_OK)
@@ -722,21 +736,21 @@ main (int argc, char *argv[])
 	gsasl_server_finish (xctx);
     }
 
-  if (imap && !writeln(". LOGOUT"))
+  if (imap && !writeln (". LOGOUT"))
     return 1;
 
   if (sockfh)
     {
       /* read "* BYE ..." */
-      if (!readln(input, MAX_LINE_LENGTH))
+      if (!readln (input, MAX_LINE_LENGTH))
 	return 1;
 
       /* read ". OK ..." */
-      if (!readln(input, MAX_LINE_LENGTH))
+      if (!readln (input, MAX_LINE_LENGTH))
 	return 1;
 
-      shutdown(sockfd, SHUT_RDWR);
-      fclose(sockfh);
+      shutdown (sockfd, SHUT_RDWR);
+      fclose (sockfh);
     }
 
   gsasl_done (ctx);
