@@ -1,5 +1,5 @@
 /* internal.h	internal header file for gsasl
- * Copyright (C) 2002  Simon Josefsson
+ * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -50,19 +50,23 @@
 #include <netdb.h>
 #endif
 #ifdef HAVE_SYS_SOCKET_H
-#include <sys/socket.h>        /* for AF_INET */
+#include <sys/socket.h>		/* for AF_INET */
 #endif
 #ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>        /* select() */
+#include <sys/types.h>		/* select() */
 #endif
 #ifdef HAVE_SYS_TIME_H
-#include <sys/time.h>        /* select() */
+#include <sys/time.h>		/* select() */
 #endif
 #ifdef HAVE_ERRNO_H
-#include <errno.h> /* strerror */
+#include <errno.h>		/* strerror */
 #endif
 #if defined HAVE_DECL_ERRNO && !HAVE_DECL_ERRNO
-extern int errno;
+/* extern int errno; */
+#endif
+
+#ifdef HAVE_NETINET_IN_H
+#include <netinet/in.h>
 #endif
 
 #ifdef HAVE_LOCALE_H
@@ -75,11 +79,8 @@ extern int errno;
 #include <argp.h>
 #include <gsasl.h>
 
-#ifdef ENABLE_NLS
-extern char *_gsasl_gettext (const char *str);
-#define _(String) _gsasl_gettext (String)
+#define _(String) dgettext (PACKAGE, String)
 #define gettext_noop(String) String
 #define N_(String) gettext_noop (String)
-#endif
 
 #endif /* _INTERNAL_H */
